<x-filament::widget>
    <x-filament::card>
        <div class="flex items-center space-x-4">
            {{-- Bagian gambar admin --}}
            <div class="flex-shrink-0">
                {{-- Anda bisa menampilkan avatar atau ikon default --}}
                <img class="h-16 w-16 rounded-full object-cover" src="{{ asset('images/kab_logo.png') }}" alt="{{ $this->getUserName() }}">
            </div>
            
            {{-- Bagian teks sambutan --}}
            <div class="" style="margin-left: 10px">
                <h2 class="text-xl font-bold tracking-tight text-gray-950 dark:text-white sm:text-2xl">
                    Halo, Selamat Datang {{ $this->getUserName() }}
                </h2>
                <p class="text-sm text-gray-500 dark:text-gray-400">
                    Anda login sebagai <span class="font-semibold text-primary-500">{{ Str::title(str_replace('_', ' ', $this->getUserRole())) }}</span>.
                    {{-- Tambahkan deskripsi atau informasi lain di sini --}}
                    Sistem Inventaris Penduduk Desa Raksajaya.
                </p>
            </div>
        </div>
    </x-filament::card>
</x-filament::widget>